@@ -250,8 +250,7 @@ class Gallery(View):
 <div class="list grid" style="column-gap: 10px;">
 
 <% for (const tile of items) { %>
-  <div class="card border-2 rounded-3 g-col-12 g-col-sm-6 g-col-md-4 mb-2" <%= m
-etadataAttrs(tile) %>>
+  <div class="card border-2 rounded-3 g-col-12 g-col-sm-6 g-col-md-4 mb-2" <%= metadataAttrs(tile) %>>
    <div class="card-body">
     <div class="card-header py-1 px-2 border-bottom border-1 ">
         <small class="card-title"><%= tile.subtitle %></small>
@@ -261,8 +260,7 @@ etadataAttrs(tile) %>>
     </div>
     <% if (tile.image) { %>
       <a href="<%- tile.path %>">
-        <img src="<%- tile.thumbnail %>" alt="<%- tile.description %>" class="ca
-rd-img-top"/>
+        <img src="<%- tile.thumbnail %>" alt="<%- tile.description %>" class="card-img-top"/>
     </a>
     <% } else { %>
         <span class="text-muted">No IIIF Image available yet</span>
@@ -441,9 +439,7 @@ class Map(View):
 
                 map_ejs = """
 ```{=html}
-<script src="https://unpkg.com/leaflet@1.8.0/dist/leaflet.js" integrity="sha512-
-BB3hKbKWOc9Ez/TAwyWxNXeoV9c1v6FIeYiBieIWkpLjauysF18NzgR1MBNBXf8/KABdlkX68nAhlwcD
-FLGPCQ==" crossorigin=""></script>
+<script src="https://unpkg.com/leaflet@1.8.0/dist/leaflet.js" integrity="sha512-BB3hKbKWOc9Ez/TAwyWxNXeoV9c1v6FIeYiBieIWkpLjauysF18NzgR1MBNBXf8/KABdlkX68nAhlwcDFLGPCQ==" crossorigin=""></script>
 <script src="leaflet.markercluster.js"></script>
 
 <div id="map" style="width: 90%; height: 800px;"></div>
@@ -451,12 +447,9 @@ FLGPCQ==" crossorigin=""></script>
 
 	var map = L.map('map').setView([53.8167, -3.0370], 6);
 
-	var tiles = L.tileLayer('https://api.mapbox.com/styles/v1/{id}/tiles/{z}
-/{x}/{y}?access_token=pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpejY4NXVycTA2emYycXBndHRqcmZ
-3N3gifQ.rJcFIG214AriISLbB6B5aw', {
+	var tiles = L.tileLayer('https://api.mapbox.com/styles/v1/{id}/tiles/{z}/{x}/{y}?access_token=pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpejY4NXVycTA2emYycXBndHRqcmZ3N3gifQ.rJcFIG214AriISLbB6B5aw', {
 		maxZoom: 18,
-		attribution: 'Map data &copy; <a href="https://www.openstreetmap
-.org/copyright">OpenStreetMap</a> contributors, ' +
+		attribution: 'Map data &copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors, ' +
 			'Imagery © <a href="https://www.mapbox.com/">Mapbox</a>'
 ,
 		id: 'mapbox/streets-v11',
@@ -466,8 +459,11 @@ FLGPCQ==" crossorigin=""></script>
 
         var markers = L.markerClusterGroup();
 <% for (const item of items) { %>
-	markers.addLayer(L.marker([<%= item.lat %>, <%= item.lon %>]).bindPopup(
-'<%= String(item.title).replace(/'/g, "\\'") %>'));
+    <% if (item.title != "") %>
+	  markers.addLayer(L.marker([<%= item.lat %>, <%= item.lon %>]).bindPopup('<%= String(item.title).replace(/\\\'/g, "\\\'") %>'));
+    <% else %>
+	  markers.addLayer(L.marker([<%= item.lat %>, <%= item.lon %>]).bindPopup(""));
+    <% end %>
 <% } %>
 
       map.addLayer(markers);
